@@ -349,6 +349,9 @@ public:
      * 注意：如果快捷键会打开下拉列表，则不能使用全局快捷键处理
      */
     void initShortcut();
+    void initToolBarShortcut();
+    void initSaveShortcut();
+
     void initLaunchMode(const QString &launchMode);
     //void delayScreenshot(double num);
     void fullScreenshot();
@@ -393,6 +396,9 @@ public:
      * 确保不会功能问题
      */
     void initTreelandtAttributes();
+
+    void setToolbarVisable(bool visable) { isHideToolBar =  visable;};
+
 signals:
     void releaseEvent();
     void saveActionTriggered();
@@ -407,6 +413,7 @@ signals:
      * @brief saveClipboardComing 数据是否已传递到剪切板
      */
     void saveClipboardComing();
+    void screenshotSaved(const QString &savePath); // 截图保存完成信号，返回保存路径
 public slots:
     void onExit();
     /**
@@ -476,6 +483,12 @@ public slots:
      */
     void changeShotToolEvent(const QString &func);
     void saveScreenShot();
+    void saveScreenShotToClipboardOnly();
+    void saveScreenShotToFile();
+    void prepareScreenshot();
+    void hideScreenshotTips();
+    void captureScreenshotImage();
+    void finishScreenshot();
     bool saveAction(const QPixmap &pix);
     void sendNotify(SaveAction saveAction, QString saveFilePath, const bool succeed);
     void reloadImage(QString effect, int radius);
@@ -1382,6 +1395,7 @@ private:
 
     bool isWayland = false;
     // Note: m_toolBar already exists as ShowButtons *m_showButtons
+    bool isHideToolBar = false;
 };
 
 #endif //MAINWINDOW_H
