@@ -1,5 +1,5 @@
 // Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -29,7 +29,7 @@ public slots:
     void setUndoEnable(bool status);
 
 protected:
-    void enterEvent(QEvent *e);
+    void enterEvent(QEnterEvent *e);
 private:
     DMenu *m_menu;
     QAction *m_unDoAct;
