@@ -16,7 +16,7 @@
 #include <DFloatingWidget>
 
 
-
+class MainWindow;
 DWIDGET_USE_NAMESPACE
 class ToolBarWidget : public DBlurEffectWidget
 {
@@ -32,6 +32,8 @@ signals:
     void sendOcrButtonClicked(); // ocr被点击
     void sendCloseButtonClicked();// 关闭按钮被点击
     void sendSaveButtonClicked();
+    void signalSaveToLocalButtonClicked();
+
 protected:
     void initToolBarWidget(); //初始化工具栏
     /**
@@ -40,6 +42,18 @@ protected:
      * @param event
      */
     void mouseMoveEvent(QMouseEvent *event) override;
+    
+    /**
+     * @brief 重写鼠标进入事件：确保鼠标进入工具栏时工具栏保持显示
+     * @param event
+     */
+    void enterEvent(QEnterEvent *event) override;
+    
+    /**
+     * @brief 重写鼠标离开事件：当鼠标离开工具栏且不在主窗口上时隐藏工具栏
+     * @param event
+     */
+    void leaveEvent(QEvent *event) override;
 private:
     MainToolWidget *m_mainTool;
     SubToolWidget *m_subTool;
