@@ -11,7 +11,7 @@
 
 #include <DLabel>
 #include <DStackedWidget>
-
+#include <DVerticalLine>
 #include <QObject>
 
 DWIDGET_USE_NAMESPACE
@@ -49,6 +49,11 @@ public:
      */
     void installHint(QWidget *w, QWidget *hint);
 
+    /**
+     * @brief 更新保存按钮的提示信息，显示实际保存路径
+     */
+    void updateSaveButtonTip();
+
     /**
      * @brief 设置禁止滚动截图
      */
@@ -136,13 +141,9 @@ private:
     ToolButton *m_cancelButton = nullptr;
     ToolButton *m_recorderButton = nullptr;
     /**
-     * @brief 截图功能中矩形工具按钮
+     * @brief 几何图形工具按钮
      */
-    ToolButton *m_rectButton = nullptr;
-    /**
-     * @brief 截图功能中圆形工具按钮
-     */
-    ToolButton *m_circleButton = nullptr;
+    ToolButton *m_gioButton = nullptr;
     /**
      * @brief 截图功能中直线工具按钮
      */
@@ -182,6 +183,7 @@ private:
      */
     ToolButton *m_shotOptionButton = nullptr;
     HintFilter *hintFilter = nullptr;
+    ToolButton *m_saveLocalDirButton = nullptr;
     /**
      * @brief m_optionMenu 截图的选项菜单
      */
@@ -217,6 +219,8 @@ private:
      */
     QAction *m_scrollChangeSaveToSpecialPath = nullptr;
     MainWindow *m_pMainWindow = nullptr;
+    DVerticalLine* m_saveSeperatorBeg= nullptr;
+    DVerticalLine* m_saveSeperatorEnd= nullptr;
 };
 
 #endif // SUBTOOLWIDGET_H
