@@ -32,8 +32,9 @@ const int TOOLBAR_HEIGHT = 68;
 const int TOOLBAR_WIDTH = 425;
 }
 
-ToolBarWidget::ToolBarWidget(MainWindow *pMainwindow, DWidget *parent)
+ToolBarWidget::ToolBarWidget(MainWindow *pMainwindow, DWidget *parent, bool hideToolBar)
     : DFloatingWidget(parent)
+    , m_hideToolBar(hideToolBar)
 {
     qCDebug(dsrApp) << "ToolBarWidget constructor called.";
     setBlurBackgroundEnabled(true);
@@ -53,28 +54,40 @@ ToolBarWidget::ToolBarWidget(MainWindow *pMainwindow, DWidget *parent)
     m_hSeparatorLine->setFixedHeight(1);
     //分配pMainwindow主窗口指针给SubToolWidget（ToolTips需要该指针）
     m_subTool = new SubToolWidget(pMainwindow, this);
-
+    // m_subTool->setVisible(false);
     //关闭按钮
     m_closeButton = new ToolButton(this);
     m_closeButton->setCheckable(false);
     m_confirmButton = new ToolButton(this);
     m_confirmButton->setCheckable(false);
+
     m_closeButton->setIconSize(QSize(36, 36));
     m_confirmButton->setIconSize(QSize(36, 36));
     m_closeButton->setFixedSize(QSize(36, 36));
     m_confirmButton->setFixedSize(QSize(36, 36));
     m_closeButton->setIcon(QIcon::fromTheme("close"));
     m_confirmButton->setIcon(QIcon::fromTheme("confirm"));
+
     m_subTool->installTipHint(m_closeButton, tr("Close (Esc)"));
-    m_subTool->installTipHint(m_confirmButton, tr("OK (Enter)"));
+    m_subTool->installTipHint(m_confirmButton, tr("Copy to clipboard (Enter)"));
+
     Utils::setAccessibility(m_closeButton, AC_TOOLBARWIDGET_CLOSE_BUTTON_TOOL);
     Utils::setAccessibility(m_confirmButton, AC_TOOLBARWIDGET_CLOSE_BUTTON_TOOL);
+
+    // 当从uos ai的调用过来则将该窗口隐藏
+    if (false)
+        m_subTool->setVisible(false);
+
     setFixedHeight(TOOLBAR_HEIGHT);
     if (Utils::is3rdInterfaceStart) {
         qCDebug(dsrApp) << "Setting minimum width for 3rd interface mode";
         m_subTool->setMinimumWidth(TOOLBAR_WIDTH - 160); //减去隐藏按钮的最小宽度和
     }
-
+    qWarning()<<"hideToolBar"<<m_hideToolBar;
+    if (m_hideToolBar)
+    {
+        m_subTool->hide();
+    }
     QHBoxLayout *hLayout = new QHBoxLayout();
     hLayout->setContentsMargins(0, 0, 0, 0);
     hLayout->setSpacing(0);
@@ -86,7 +99,13 @@ ToolBarWidget::ToolBarWidget(MainWindow *pMainwindow, DWidget *parent)
     setLayout(hLayout);
 
     connect(m_confirmButton, &ToolButton::clicked, pMainwindow, &MainWindow::confirm);
-    connect(m_closeButton, &ToolButton::clicked, pMainwindow, &MainWindow::exitApp);    
+
+    connect(m_closeButton, &ToolButton::clicked, pMainwindow, [=](){
+        if (m_hideToolBar) {
+            emit pMainwindow->screenshotSaved("");
+        }
+        pMainwindow->exitApp();
+    });
     connect(m_subTool, &SubToolWidget::keyBoardButtonClicked, pMainwindow, &MainWindow::changeKeyBoardShowEvent);
     connect(m_subTool, &SubToolWidget::mouseBoardButtonClicked, pMainwindow, &MainWindow::changeMouseShowEvent);
 
@@ -97,7 +116,8 @@ ToolBarWidget::ToolBarWidget(MainWindow *pMainwindow, DWidget *parent)
     if (!connectHandle) {
         qCDebug(dsrApp) << "Connect cameraActionChecked signal failed!";
     }
-    connect(m_subTool, SIGNAL(changeShotToolFunc(const QString &)), pMainwindow, SLOT(changeShotToolEvent(const QString &)));
+    connect(m_subTool, &SubToolWidget::changeShotToolFunc, pMainwindow, &MainWindow::changeShotToolEvent);
+    connect(m_subTool, &SubToolWidget::changeShotToolFunc, this, &ToolBarWidget::changeShotToolEvent);
 }
 
 void ToolBarWidget::setScrollShotDisabled(const bool state)
@@ -131,6 +151,11 @@ int ToolBarWidget::getFuncSubToolX(QString &func)
     return m_subTool->getFuncSubToolX(func);
 }
 
+void ToolBarWidget::setHideToolbar(bool hidetoolbar)
+{
+    m_hideToolBar = hidetoolbar;
+}
+
 void ToolBarWidget::setRecordLaunchFromMain(const unsigned int funType)
 {
     qCDebug(dsrApp) << "ToolBarWidget::setRecordLaunchFromMain called with function type:" << funType;
@@ -161,6 +186,10 @@ void ToolBarWidget::setCameraDeviceEnable(bool status)
     qCDebug(dsrApp) << "ToolBarWidget::setCameraDeviceEnable called with status:" << status;
     m_subTool->setCameraDeviceEnable(status);
 }
+
+void ToolBarWidget::changeShotToolEvent(const QString &func)
+{
+}
 /*
 void ToolBarWidget::setExpand(bool expand, QString shapeType)
 {
@@ -316,12 +345,12 @@ void ToolBar::currentFunctionMode(QString shapeType)
     emit currentFunctionToMain(shapeType);
 }
 
-void ToolBar::initToolBar(MainWindow *pmainWindow)
+void ToolBar::initToolBar(MainWindow *pmainWindow, bool hideToolbar)
 {
     m_pMainWindow = pmainWindow;
     setFixedHeight(TOOLBAR_HEIGHT);
 
-    m_toolbarWidget = new ToolBarWidget(pmainWindow, this);
+    m_toolbarWidget = new ToolBarWidget(pmainWindow, this, hideToolbar);
     QHBoxLayout *vLayout = new QHBoxLayout();
     vLayout->setSizeConstraint(QLayout::SetFixedSize);
     vLayout->setContentsMargins(0, 0, 0, 0);
@@ -383,3 +412,4 @@ QRect ToolBar::getShotOptionRect(){
 ToolBar::~ToolBar()
 {
 }
+
