@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="cs">
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -23,17 +25,6 @@ v oznamovací oblasti panelu nebo stiskněte klávesovou zkratku</translation>
         <translation>Nahrávání</translation>
     </message>
 </context>
-<context>
-    <name>MainToolWidget</name>
-    <message>
-        <source>Record</source>
-        <translation>Pořídit záznam</translation>
-    </message>
-    <message>
-        <source>Screenshot</source>
-        <translation>Pořídit snímek obrazovky</translation>
-    </message>
-</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -96,10 +87,6 @@ v oznamovací oblasti panelu nebo stiskněte klávesovou zkratku</translation>
         <source>Screenshot</source>
         <translation>Snímek obrazovky</translation>
     </message>
-    <message>
-        <source>Screenshot failed.</source>
-        <translation>Pořízení snímku obrazovky se nezdařilo.</translation>
-    </message>
     <message>
         <source>Scrollshot</source>
         <translation>Snímek z celého posuvníku</translation>
@@ -451,15 +438,6 @@ Stiskněte a podržte klávesu Shift pro kreslení přímky</translation>
         <translation>Nastavení velikosti textu (posunutím ji nastavíte)</translation>
     </message>
 </context>
-<context>
-    <name>StartTooltip</name>
-    <message>
-        <source>Click or drag to
-select the area to record</source>
-        <translation>Klepněte nebo táhněte
-pro vybrání oblasti k nahrávání</translation>
-    </message>
-</context>
 <context>
     <name>SubToolWidget</name>
     <message>
@@ -574,18 +552,6 @@ pro vybrání oblasti k nahrávání</translation>
         <source>Videos</source>
         <translation>Videa</translation>
     </message>
-    <message>
-        <source>Rectangle (R)
-Press and hold Shift to draw a square</source>
-        <translation>Obdélník (R)
-Stiskněte a podržte klávesu Shift pro kreslení čtverce</translation>
-    </message>
-    <message>
-        <source>Ellipse (O)
-Press and hold Shift to draw a circle</source>
-        <translation>Elipsa (O)
-Stiskněte a podržte klávesu Shift pro kreslení kruhu</translation>
-    </message>
     <message>
         <source>Line (L)
 Press and hold Shift to draw a vertical or horizontal line</source>
@@ -630,18 +596,10 @@ Stiskněte a podržte klávesu Shift pro kreslení svislé nebo vodorovné šipk
         <source>Record</source>
         <translation>Pořídit záznam</translation>
     </message>
-    <message>
-        <source>Clipboard</source>
-        <translation>Schránka</translation>
-    </message>
     <message>
         <source>Pictures</source>
         <translation>Obrázky</translation>
     </message>
-    <message>
-        <source>Folder</source>
-        <translation>Složka</translation>
-    </message>
     <message>
         <source>Set a path on save</source>
         <translation>Nastavit popis umístění při ukládání</translation>
@@ -690,6 +648,51 @@ Stiskněte a podržte klávesu Shift pro kreslení svislé nebo vodorovné šipk
         <source>Extract Text</source>
         <translation>Rozpoznat text</translation>
     </message>
+    <message>
+        <source>Geometric Tools (R)
+Hold down Shift to draw squares or circles.</source>
+        <translation>Držte stisknutou klávesu Shift pro kreslení čtverců nebo kruhů.</translation>
+    </message>
+    <message>
+        <source>Save to local</source>
+        <translation>Uložit do místního</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Uložit do plochy</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Uložit do obrázků</translation>
+    </message>
+    <message>
+        <source>Save to %1</source>
+        <translation>Uložit do %1</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Určené umístění</translation>
+    </message>
+    <message>
+        <source>Custom Location</source>
+        <translation>Vlastní umístění</translation>
+    </message>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Každá otázka</translation>
+    </message>
+    <message>
+        <source>Update location on save</source>
+        <translation>Aktualizovat umístění při ukládání</translation>
+    </message>
+    <message>
+        <source>Save to desktop</source>
+        <translation>Uložit do plochy</translation>
+    </message>
+    <message>
+        <source>Save to pictures</source>
+        <translation>Uložit do obrázků</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
@@ -698,8 +701,8 @@ Stiskněte a podržte klávesu Shift pro kreslení svislé nebo vodorovné šipk
         <translation>Zavřít (Esc)</translation>
     </message>
     <message>
-        <source>OK (Enter)</source>
-        <translation>OK (Enter)</translation>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Vložit do schránky (Enter)</translation>
     </message>
 </context>
 <context>
@@ -720,11 +723,4 @@ Stiskněte a podržte klávesu Shift pro kreslení svislé nebo vodorovné šipk
         <translation>Ukončit</translation>
     </message>
 </context>
-<context>
-    <name>VoiceRecordProcess</name>
-    <message>
-        <source>New recording</source>
-        <translation>Nová nahrávka</translation>
-    </message>
-</context>
 </TS>
