@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="fi">
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -23,17 +25,6 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
         <translation>Tallennus</translation>
     </message>
 </context>
-<context>
-    <name>MainToolWidget</name>
-    <message>
-        <source>Record</source>
-        <translation>Tallenna</translation>
-    </message>
-    <message>
-        <source>Screenshot</source>
-        <translation>Kaappaus</translation>
-    </message>
-</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -96,10 +87,6 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
         <source>Screenshot</source>
         <translation>Kaappaus</translation>
     </message>
-    <message>
-        <source>Screenshot failed.</source>
-        <translation>Kaappaus epäonnistui.</translation>
-    </message>
     <message>
         <source>Scrollshot</source>
         <translation>Vierittävä kaappaus</translation>
@@ -451,15 +438,6 @@ Vedä suora viiva pitämällä Shift-painettuna</translation>
         <translation>Muuta tekstin kokoa (vieritä säätääksesi)</translation>
     </message>
 </context>
-<context>
-    <name>StartTooltip</name>
-    <message>
-        <source>Click or drag to
-select the area to record</source>
-        <translation>Napsauta tai vedä
-valitse tallennettava alue</translation>
-    </message>
-</context>
 <context>
     <name>SubToolWidget</name>
     <message>
@@ -574,18 +552,6 @@ valitse tallennettava alue</translation>
         <source>Videos</source>
         <translation>Videot</translation>
     </message>
-    <message>
-        <source>Rectangle (R)
-Press and hold Shift to draw a square</source>
-        <translation>Suorakulmio (R)
-Piirrä neliö pitämällä Shift-painettuna</translation>
-    </message>
-    <message>
-        <source>Ellipse (O)
-Press and hold Shift to draw a circle</source>
-        <translation>Ellipsi (O).
-Piirrä ympyrä pitämällä Shift-painettuna</translation>
-    </message>
     <message>
         <source>Line (L)
 Press and hold Shift to draw a vertical or horizontal line</source>
@@ -630,18 +596,10 @@ Vedä suora pysty- tai vaakanuoli pitämällä Shift-painettuna</translation>
         <source>Record</source>
         <translation>Tallenna</translation>
     </message>
-    <message>
-        <source>Clipboard</source>
-        <translation>Leikepöydälle</translation>
-    </message>
     <message>
         <source>Pictures</source>
         <translation>Kuvat</translation>
     </message>
-    <message>
-        <source>Folder</source>
-        <translation>Kansio</translation>
-    </message>
     <message>
         <source>Set a path on save</source>
         <translation>Aseta tallennuspolku</translation>
@@ -690,6 +648,52 @@ Vedä suora pysty- tai vaakanuoli pitämällä Shift-painettuna</translation>
         <source>Extract Text</source>
         <translation>Poimi tekstiä</translation>
     </message>
+    <message>
+        <source>Geometric Tools (R)
+Hold down Shift to draw squares or circles.</source>
+        <translation>Geometriset työkalut (R)
+Pidä Shift-näppäintä painettuna piirtääksesi neliöitä tai ympyröitä.</translation>
+    </message>
+    <message>
+        <source>Save to local</source>
+        <translation>Tallenna paikallisesti</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Tallenna työpöydälle</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Tallenna kuvakkeisiin</translation>
+    </message>
+    <message>
+        <source>Save to %1</source>
+        <translation>Tallenna nimellä %1</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Määritetty sijainti</translation>
+    </message>
+    <message>
+        <source>Custom Location</source>
+        <translation>Mukautettu sijainti</translation>
+    </message>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Jokainen kysely</translation>
+    </message>
+    <message>
+        <source>Update location on save</source>
+        <translation>Päivitä sijainti tallessa</translation>
+    </message>
+    <message>
+        <source>Save to desktop</source>
+        <translation>Tallenna työpöydälle</translation>
+    </message>
+    <message>
+        <source>Save to pictures</source>
+        <translation>Tallenna kuvakkeisiin</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
@@ -698,8 +702,8 @@ Vedä suora pysty- tai vaakanuoli pitämällä Shift-painettuna</translation>
         <translation>Sulje (Esc)</translation>
     </message>
     <message>
-        <source>OK (Enter)</source>
-        <translation>OK (Enter)</translation>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Kopioi leikepöydälle (Enter)</translation>
     </message>
 </context>
 <context>
@@ -720,11 +724,4 @@ Vedä suora pysty- tai vaakanuoli pitämällä Shift-painettuna</translation>
         <translation>Poistu</translation>
     </message>
 </context>
-<context>
-    <name>VoiceRecordProcess</name>
-    <message>
-        <source>New recording</source>
-        <translation>Uusi äänitys</translation>
-    </message>
-</context>
 </TS>
