@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="gl_ES">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="gl_ES">
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -23,17 +25,6 @@ ou prema de novo o atallo para deixar de gravar</translation>
         <translation>Gravando</translation>
     </message>
 </context>
-<context>
-    <name>MainToolWidget</name>
-    <message>
-        <source>Record</source>
-        <translation>Gravar</translation>
-    </message>
-    <message>
-        <source>Screenshot</source>
-        <translation>Captura de pantalla</translation>
-    </message>
-</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -96,10 +87,6 @@ ou prema de novo o atallo para deixar de gravar</translation>
         <source>Screenshot</source>
         <translation>Captura de pantalla</translation>
     </message>
-    <message>
-        <source>Screenshot failed.</source>
-        <translation>Produciuse un erro na captura de pantalla.</translation>
-    </message>
     <message>
         <source>Scrollshot</source>
         <translation>Captura de desprazamento</translation>
@@ -451,15 +438,6 @@ Manteña premida a tecla Maiúsculas para debuxar unha liña recta</translation>
         <translation>Axustar o tamaño do texto (Desprácese para axustalo)</translation>
     </message>
 </context>
-<context>
-    <name>StartTooltip</name>
-    <message>
-        <source>Click or drag to
-select the area to record</source>
-        <translation>Fai clic ou arrastra
-para seleccionar a área a gravar</translation>
-    </message>
-</context>
 <context>
     <name>SubToolWidget</name>
     <message>
@@ -574,18 +552,6 @@ para seleccionar a área a gravar</translation>
         <source>Videos</source>
         <translation>Vídeos</translation>
     </message>
-    <message>
-        <source>Rectangle (R)
-Press and hold Shift to draw a square</source>
-        <translation>Rectángulo (R)
-Manteña premida a tecla Maiúsculas para debuxar un cadrado</translation>
-    </message>
-    <message>
-        <source>Ellipse (O)
-Press and hold Shift to draw a circle</source>
-        <translation>Elipse (O)
-Manteña premida a tecla Maiúsculas para debuxar un círculo</translation>
-    </message>
     <message>
         <source>Line (L)
 Press and hold Shift to draw a vertical or horizontal line</source>
@@ -630,18 +596,10 @@ Manteña premida a tecla Maiúsculas para debuxar unha frecha vertical ou horizo
         <source>Record</source>
         <translation>Gravar</translation>
     </message>
-    <message>
-        <source>Clipboard</source>
-        <translation>Portapapeis</translation>
-    </message>
     <message>
         <source>Pictures</source>
         <translation>Imaxes</translation>
     </message>
-    <message>
-        <source>Folder</source>
-        <translation>Cartafol</translation>
-    </message>
     <message>
         <source>Set a path on save</source>
         <translation>Establece un camiño ao gardar</translation>
@@ -690,6 +648,52 @@ Manteña premida a tecla Maiúsculas para debuxar unha frecha vertical ou horizo
         <source>Extract Text</source>
         <translation>Extraer texto</translation>
     </message>
+    <message>
+        <source>Geometric Tools (R)
+Hold down Shift to draw squares or circles.</source>
+        <translation>Ferramentas xeométricas (R)
+Mantén premida a tecla Maiús para debuxar cadrados ou círculos.</translation>
+    </message>
+    <message>
+        <source>Save to local</source>
+        <translation>Gardar no local</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Gardar no escritorio</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Gardar en imaxes</translation>
+    </message>
+    <message>
+        <source>Save to %1</source>
+        <translation>Gardar en %1</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Localización especificada</translation>
+    </message>
+    <message>
+        <source>Custom Location</source>
+        <translation>Localización personalizada</translation>
+    </message>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Cada consulta</translation>
+    </message>
+    <message>
+        <source>Update location on save</source>
+        <translation>Actualizar a localización ao gardar</translation>
+    </message>
+    <message>
+        <source>Save to desktop</source>
+        <translation>Gardar no escritorio</translation>
+    </message>
+    <message>
+        <source>Save to pictures</source>
+        <translation>Gardar en imaxes</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
@@ -698,8 +702,8 @@ Manteña premida a tecla Maiúsculas para debuxar unha frecha vertical ou horizo
         <translation>Pechar (Esc)</translation>
     </message>
     <message>
-        <source>OK (Enter)</source>
-        <translation>Aceptar (Enter)</translation>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Copiar ao portapapeis (Enter)</translation>
     </message>
 </context>
 <context>
@@ -720,11 +724,4 @@ Manteña premida a tecla Maiúsculas para debuxar unha frecha vertical ou horizo
         <translation>Saír</translation>
     </message>
 </context>
-<context>
-    <name>VoiceRecordProcess</name>
-    <message>
-        <source>New recording</source>
-        <translation>Nova gravación</translation>
-    </message>
-</context>
 </TS>
