@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="uk">
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -23,17 +25,6 @@ or press the shortcut again to stop recording</source>
         <translation>Записування</translation>
     </message>
 </context>
-<context>
-    <name>MainToolWidget</name>
-    <message>
-        <source>Record</source>
-        <translation>Записати</translation>
-    </message>
-    <message>
-        <source>Screenshot</source>
-        <translation>Знімок</translation>
-    </message>
-</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -96,10 +87,6 @@ or press the shortcut again to stop recording</source>
         <source>Screenshot</source>
         <translation>Знімок</translation>
     </message>
-    <message>
-        <source>Screenshot failed.</source>
-        <translation>Не вдалося створити знімок.</translation>
-    </message>
     <message>
         <source>Scrollshot</source>
         <translation>Знімок із гортанням</translation>
@@ -110,7 +97,7 @@ or press the shortcut again to stop recording</source>
     </message>
     <message>
         <source>deepin-screen-recorder</source>
-        <translation type="unfinished"/>
+        <translation>Засіб запису екрана Deepin</translation>
     </message>
     <message>
         <source>Open Folder</source>
@@ -118,7 +105,7 @@ or press the shortcut again to stop recording</source>
     </message>
     <message>
         <source>Screenshot finished and copy to clipboard</source>
-        <translation type="unfinished"/>
+        <translation>Знімок завершено і скопійовано до буфера обміну</translation>
     </message>
 </context>
 <context>
@@ -451,15 +438,6 @@ Press and hold Shift to draw a straight line</source>
         <translation>Скоригувати розмір символів (крутіть коліщатко для зміни)</translation>
     </message>
 </context>
-<context>
-    <name>StartTooltip</name>
-    <message>
-        <source>Click or drag to
-select the area to record</source>
-        <translation>Натисніть або перетяніть,
-щоб вибрати область для запису</translation>
-    </message>
-</context>
 <context>
     <name>SubToolWidget</name>
     <message>
@@ -574,18 +552,6 @@ select the area to record</source>
         <source>Videos</source>
         <translation>Відео</translation>
     </message>
-    <message>
-        <source>Rectangle (R)
-Press and hold Shift to draw a square</source>
-        <translation>Прямокутник (R)
-Натисніть і утримуйте клавішу Shift, щоб намалювати квадрат</translation>
-    </message>
-    <message>
-        <source>Ellipse (O)
-Press and hold Shift to draw a circle</source>
-        <translation>Еліпс (O)
-Натисніть і утримуйте клавішу Shift, щоб намалювати коло</translation>
-    </message>
     <message>
         <source>Line (L)
 Press and hold Shift to draw a vertical or horizontal line</source>
@@ -630,18 +596,10 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <source>Record</source>
         <translation>Записати</translation>
     </message>
-    <message>
-        <source>Clipboard</source>
-        <translation>Буфер обміну</translation>
-    </message>
     <message>
         <source>Pictures</source>
         <translation>Зображення</translation>
     </message>
-    <message>
-        <source>Folder</source>
-        <translation>Тека</translation>
-    </message>
     <message>
         <source>Set a path on save</source>
         <translation>Встановити шлях для збереження</translation>
@@ -690,6 +648,52 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <source>Extract Text</source>
         <translation>Видобути текст</translation>
     </message>
+    <message>
+        <source>Geometric Tools (R)
+Hold down Shift to draw squares or circles.</source>
+        <translation>Геометричні інструменти (R)
+Утримуйте Shift для малювання квадратів або кіл.</translation>
+    </message>
+    <message>
+        <source>Save to local</source>
+        <translation>Зберегти локально</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Зберегти на стільниці</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Зберегти в зображення</translation>
+    </message>
+    <message>
+        <source>Save to %1</source>
+        <translation>Зберегти до %1</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Вказане місце</translation>
+    </message>
+    <message>
+        <source>Custom Location</source>
+        <translation>Власний шлях</translation>
+    </message>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Кожне запитування</translation>
+    </message>
+    <message>
+        <source>Update location on save</source>
+        <translation>Оновлення місця збереження</translation>
+    </message>
+    <message>
+        <source>Save to desktop</source>
+        <translation>Зберегти на стільниці</translation>
+    </message>
+    <message>
+        <source>Save to pictures</source>
+        <translation>Зберегти в зображення</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
@@ -698,8 +702,8 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <translation>Закрити (Esc)</translation>
     </message>
     <message>
-        <source>OK (Enter)</source>
-        <translation>Гаразд (Enter)</translation>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Скопіювати до буфера обміну (Enter)</translation>
     </message>
 </context>
 <context>
@@ -720,11 +724,4 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <translation>Вийти</translation>
     </message>
 </context>
-<context>
-    <name>VoiceRecordProcess</name>
-    <message>
-        <source>New recording</source>
-        <translation>Новий запис</translation>
-    </message>
-</context>
-</TS>
\ No newline at end of file
+</TS>
