@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="zh_CN">
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -23,17 +25,6 @@ or press the shortcut again to stop recording</source>
         <translation>录屏</translation>
     </message>
 </context>
-<context>
-    <name>MainToolWidget</name>
-    <message>
-        <source>Record</source>
-        <translation>录屏</translation>
-    </message>
-    <message>
-        <source>Screenshot</source>
-        <translation>截图</translation>
-    </message>
-</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -96,10 +87,6 @@ or press the shortcut again to stop recording</source>
         <source>Screenshot</source>
         <translation>截图</translation>
     </message>
-    <message>
-        <source>Screenshot failed.</source>
-        <translation>截图失败。</translation>
-    </message>
     <message>
         <source>Scrollshot</source>
         <translation>滚动截图</translation>
@@ -451,14 +438,6 @@ Press and hold Shift to draw a straight line</source>
         <translation>调整文字大小（鼠标滚轮）</translation>
     </message>
 </context>
-<context>
-    <name>StartTooltip</name>
-    <message>
-        <source>Click or drag to
-select the area to record</source>
-        <translation>点击或拖动以选择要录制的区域</translation>
-    </message>
-</context>
 <context>
     <name>SubToolWidget</name>
     <message>
@@ -563,7 +542,7 @@ select the area to record</source>
     </message>
     <message>
         <source>Save to</source>
-        <translation>保存到</translation>
+        <translation>保存方式</translation>
     </message>
     <message>
         <source>Desktop</source>
@@ -573,18 +552,6 @@ select the area to record</source>
         <source>Videos</source>
         <translation>视频</translation>
     </message>
-    <message>
-        <source>Rectangle (R)
-Press and hold Shift to draw a square</source>
-        <translation>矩形（R）
-按住Shift可画正方形</translation>
-    </message>
-    <message>
-        <source>Ellipse (O)
-Press and hold Shift to draw a circle</source>
-        <translation>椭圆（O）
-按住Shift可画圆形</translation>
-    </message>
     <message>
         <source>Line (L)
 Press and hold Shift to draw a vertical or horizontal line</source>
@@ -629,18 +596,10 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <source>Record</source>
         <translation>录屏</translation>
     </message>
-    <message>
-        <source>Clipboard</source>
-        <translation>剪贴板</translation>
-    </message>
     <message>
         <source>Pictures</source>
         <translation>图片</translation>
     </message>
-    <message>
-        <source>Folder</source>
-        <translation>指定位置</translation>
-    </message>
     <message>
         <source>Set a path on save</source>
         <translation>保存时设置位置</translation>
@@ -689,6 +648,52 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <source>Extract Text</source>
         <translation>识别文字</translation>
     </message>
+    <message>
+        <source>Save to local</source>
+        <translation>保存到本地</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>指定位置</translation>
+    </message>
+    <message>
+        <source>Custom Location</source>
+        <translation>自定义位置</translation>
+    </message>
+    <message>
+        <source>Each inquiry</source>
+        <translation>每次询问</translation>
+    </message>
+    <message>
+        <source>Update location on save</source>
+        <translation>保存时更新位置</translation>
+    </message>
+    <message>
+        <source>Geometric Tools (R)
+Hold down Shift to draw squares or circles.</source>
+        <translation>几何工具 (R)
+按住Shift可画正方形/正圆</translation>
+    </message>
+    <message>
+        <source>Save to %1</source>
+        <translation>保存到%1</translation>
+    </message>
+    <message>
+        <source>Save to desktop</source>
+        <translation>保存到桌面</translation>
+    </message>
+    <message>
+        <source>Save to pictures</source>
+        <translation>保存到图片</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>保存到桌面</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>保存到图片</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
@@ -697,8 +702,8 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <translation>关闭 Esc</translation>
     </message>
     <message>
-        <source>OK (Enter)</source>
-        <translation>确认 Enter</translation>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>复制到剪贴板</translation>
     </message>
 </context>
 <context>
@@ -719,11 +724,4 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <translation>退出</translation>
     </message>
 </context>
-<context>
-    <name>VoiceRecordProcess</name>
-    <message>
-        <source>New recording</source>
-        <translation>新录音</translation>
-    </message>
-</context>
 </TS>
