@@ -1,50 +1,39 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="zh_CN">
+<TS version="2.1" language="zh_HK">
 <context>
     <name>CountdownTooltip</name>
     <message>
         <source>Click the tray icon 
 or press the shortcut again to stop recording</source>
-        <translation>点击托盘图标
-或再次按下录屏快捷键停止录制</translation>
+        <translation>點擊托盤圖標
+或再次按下錄屏快捷鍵停止錄製</translation>
     </message>
     <message>
         <source>Do not rotate your screen during recording</source>
-        <translation>屏幕录制中请勿旋转屏幕</translation>
+        <translation>螢幕錄製中請勿旋轉螢幕</translation>
     </message>
 </context>
 <context>
     <name>IconWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation>截图</translation>
+        <translation>截圖</translation>
     </message>
     <message>
         <source>Recording</source>
-        <translation>录屏</translation>
-    </message>
-</context>
-<context>
-    <name>MainToolWidget</name>
-    <message>
-        <source>Record</source>
-        <translation>录屏</translation>
-    </message>
-    <message>
-        <source>Screenshot</source>
-        <translation>截图</translation>
+        <translation>錄屏</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
         <source>Screen Capture</source>
-        <translation>截图录屏</translation>
+        <translation>截圖錄屏</translation>
     </message>
     <message>
         <source>Save failed. Please save it in your home directory.</source>
-        <translation>保存失败。请保存在当前用户目录下。</translation>
+        <translation>保存失敗。請保存在當前用戶目錄下。</translation>
     </message>
     <message>
         <source>View</source>
@@ -52,7 +41,7 @@ or press the shortcut again to stop recording</source>
     </message>
     <message>
         <source>Screenshot finished</source>
-        <translation>截图完成</translation>
+        <translation>截圖完成</translation>
     </message>
     <message>
         <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
@@ -68,7 +57,7 @@ or press the shortcut again to stop recording</source>
     </message>
     <message>
         <source>select-area</source>
-        <translation>选择区域</translation>
+        <translation>選擇區域</translation>
     </message>
     <message>
         <source>Save</source>
@@ -76,7 +65,7 @@ or press the shortcut again to stop recording</source>
     </message>
     <message>
         <source>Saved to %1</source>
-        <translation>图片已保存到%1</translation>
+        <translation>圖片已保存到%1</translation>
     </message>
     <message>
         <source>Ignore</source>
@@ -84,46 +73,46 @@ or press the shortcut again to stop recording</source>
     </message>
     <message>
         <source>Clipboard</source>
-        <translation>剪贴板</translation>
+        <translation>剪貼板</translation>
     </message>
     <message>
         <source>Saving the screen recording file, please wait...</source>
-        <translation>正在保存录屏文件，请稍候...</translation>
+        <translation>正在保存錄屏文件，請稍候...</translation>
     </message>
     <message>
         <source>As the window effect is disabled during the process, the recording has to be stopped</source>
-        <translation>因在录制过程中关闭了窗口特效，录屏已结束</translation>
+        <translation>因在錄製過程中關閉了視窗特效，錄屏已結束</translation>
     </message>
     <message>
         <source>Screenshot</source>
-        <translation>截图</translation>
+        <translation>截圖</translation>
     </message>
     <message>
         <source>Scrollshot</source>
-        <translation>滚动截图</translation>
+        <translation>滾動截圖</translation>
     </message>
     <message>
         <source>Pin Screenshots</source>
-        <translation>贴图</translation>
+        <translation>貼圖</translation>
     </message>
     <message>
         <source>deepin-screen-recorder</source>
-        <translation>截图录屏</translation>
+        <translation>截圖錄屏</translation>
     </message>
     <message>
         <source>Open Folder</source>
-        <translation>打开文件夹</translation>
+        <translation>打開資料夾</translation>
     </message>
     <message>
         <source>Screenshot finished and copy to clipboard</source>
-        <translation>截图完成，文件已复制到剪贴板</translation>
+        <translation>截圖完成，文件已複製到剪貼板</translation>
     </message>
 </context>
 <context>
     <name>MenuController</name>
     <message>
         <source>Undo</source>
-        <translation>撤销</translation>
+        <translation>撤銷</translation>
     </message>
     <message>
         <source>Save</source>
@@ -138,29 +127,29 @@ or press the shortcut again to stop recording</source>
     <name>QObject</name>
     <message>
         <source>Pin Screenshots</source>
-        <translation>贴图</translation>
+        <translation>貼圖</translation>
     </message>
 </context>
 <context>
     <name>QuickPanelWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation>截图</translation>
+        <translation>截圖</translation>
     </message>
     <message>
         <source>Record</source>
-        <translation>录屏</translation>
+        <translation>錄屏</translation>
     </message>
 </context>
 <context>
     <name>RecordIconWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation>截图</translation>
+        <translation>截圖</translation>
     </message>
     <message>
         <source>Recording</source>
-        <translation>录屏</translation>
+        <translation>錄屏</translation>
     </message>
 </context>
 <context>
@@ -171,7 +160,7 @@ or press the shortcut again to stop recording</source>
     </message>
     <message>
         <source>Recording finished</source>
-        <translation>录制完毕</translation>
+        <translation>錄製完畢</translation>
     </message>
     <message>
         <source>Saved to %1</source>
@@ -179,67 +168,67 @@ or press the shortcut again to stop recording</source>
     </message>
     <message>
         <source>Record</source>
-        <translation>录屏</translation>
+        <translation>錄屏</translation>
     </message>
     <message>
         <source>Open Folder</source>
-        <translation>打开文件夹</translation>
+        <translation>打開資料夾</translation>
     </message>
 </context>
 <context>
     <name>Screenshot</name>
     <message>
         <source>Screen Capture will start in %1 seconds</source>
-        <translation>截图录屏将在%1秒后启动</translation>
+        <translation>截圖錄屏將在%1秒後啟動</translation>
     </message>
 </context>
 <context>
     <name>ScrollShotTip</name>
     <message>
         <source>Get help.</source>
-        <translation>查看帮助</translation>
+        <translation>查看幫助</translation>
     </message>
     <message>
         <source>Failed to take a continuous screenshot.</source>
-        <translation>无法继续截图，</translation>
+        <translation>無法繼續截圖，</translation>
     </message>
     <message>
         <source>Reached the bottom of the scroll area</source>
-        <translation>已到滚动区域底部</translation>
+        <translation>已到滾動區域底部</translation>
     </message>
     <message>
         <source>Reached the maximum length</source>
-        <translation>已到最大长度</translation>
+        <translation>已到最大長度</translation>
     </message>
     <message>
         <source>adjust the capture area</source>
-        <translation>调整捕捉区域</translation>
+        <translation>調整捕捉區域</translation>
     </message>
     <message>
         <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
-        <translation>滚动鼠标滚轮或单击捕捉区域</translation>
+        <translation>滾動滑鼠滾輪或單擊捕捉區域</translation>
     </message>
     <message>
         <source>Slow down the scrolling speed</source>
-        <translation>请放慢滚动速度</translation>
+        <translation>請放慢滾動速度</translation>
     </message>
     <message>
         <source>Invalid area, click to </source>
-        <translation>无效区域，点击</translation>
+        <translation>無效區域，點擊</translation>
     </message>
 </context>
 <context>
     <name>ShapesWidget</name>
     <message>
         <source>Input text here</source>
-        <translation>在此处添加文本</translation>
+        <translation>在此處添加文本</translation>
     </message>
 </context>
 <context>
     <name>Shortcut</name>
     <message>
         <source>Start/Screenshot</source>
-        <translation>启动/截图 </translation>
+        <translation>啟動/截圖 </translation>
     </message>
     <message>
         <source>Exit/Save</source>
@@ -247,23 +236,23 @@ or press the shortcut again to stop recording</source>
     </message>
     <message>
         <source>Size Adjustment</source>
-        <translation>调整区域</translation>
+        <translation>調整區域</translation>
     </message>
     <message>
         <source>Settings</source>
-        <translation>设置</translation>
+        <translation>設定</translation>
     </message>
     <message>
         <source>Quick start</source>
-        <translation>快速启动截图</translation>
+        <translation>快速啟動截圖</translation>
     </message>
     <message>
         <source>Window screenshot</source>
-        <translation>光标所在窗口截图</translation>
+        <translation>游標所在視窗截圖</translation>
     </message>
     <message>
         <source>Delay screenshot</source>
-        <translation>延时5秒截屏</translation>
+        <translation>延時5秒截屏</translation>
     </message>
     <message>
         <source>Full screenshot</source>
@@ -283,15 +272,15 @@ or press the shortcut again to stop recording</source>
     </message>
     <message>
         <source>Ellipse</source>
-        <translation>椭圆</translation>
+        <translation>橢圓</translation>
     </message>
     <message>
         <source>Line</source>
-        <translation>直线</translation>
+        <translation>直線</translation>
     </message>
     <message>
         <source>Pencil</source>
-        <translation>画笔</translation>
+        <translation>畫筆</translation>
     </message>
     <message>
         <source>Text</source>
@@ -299,79 +288,79 @@ or press the shortcut again to stop recording</source>
     </message>
     <message>
         <source>Delete</source>
-        <translation>删除选中图形</translation>
+        <translation>刪除選中圖形</translation>
     </message>
     <message>
         <source>Undo</source>
-        <translation>撤销</translation>
+        <translation>撤銷</translation>
     </message>
     <message>
         <source>Increase height up</source>
-        <translation>向上扩大选区高度</translation>
+        <translation>向上擴大選區高度</translation>
     </message>
     <message>
         <source>Increase height down</source>
-        <translation>向下扩大选区高度</translation>
+        <translation>向下擴大選區高度</translation>
     </message>
     <message>
         <source>Increase width left</source>
-        <translation>向左扩大选区宽度</translation>
+        <translation>向左擴大選區寬度</translation>
     </message>
     <message>
         <source>Increase width right</source>
-        <translation>向右扩大选区宽度</translation>
+        <translation>向右擴大選區寬度</translation>
     </message>
     <message>
         <source>Decrease height up</source>
-        <translation>向上缩小选区高度</translation>
+        <translation>向上縮小選區高度</translation>
     </message>
     <message>
         <source>Decrease height down</source>
-        <translation>向下缩小选区高度</translation>
+        <translation>向下縮小選區高度</translation>
     </message>
     <message>
         <source>Decrease width left</source>
-        <translation>向左缩小选区宽度</translation>
+        <translation>向左縮小選區寬度</translation>
     </message>
     <message>
         <source>Decrease width right</source>
-        <translation>向右缩小选区宽度</translation>
+        <translation>向右縮小選區寬度</translation>
     </message>
     <message>
         <source>Help</source>
-        <translation>帮助</translation>
+        <translation>幫助</translation>
     </message>
     <message>
         <source>Display shortcuts</source>
-        <translation>显示快捷键</translation>
+        <translation>顯示快捷鍵</translation>
     </message>
     <message>
         <source>Sound</source>
-        <translation>录音</translation>
+        <translation>錄音</translation>
     </message>
     <message>
         <source>Keystroke</source>
-        <translation>按键</translation>
+        <translation>按鍵</translation>
     </message>
     <message>
         <source>Webcam</source>
-        <translation>摄像头</translation>
+        <translation>攝像頭</translation>
     </message>
     <message>
         <source>Start recording</source>
-        <translation>快速启动录屏</translation>
+        <translation>快速啟動錄屏</translation>
     </message>
     <message>
         <source>Options</source>
-        <translation>选项</translation>
+        <translation>選項</translation>
     </message>
     <message>
         <source>Start/Recording</source>
-        <translation>启动/录屏</translation>
+        <translation>啟動/錄屏</translation>
     </message>
     <message>
         <source>Mouse</source>
-        <translation>录制鼠标</translation>
+        <translation>錄製滑鼠</translation>
     </message>
     <message>
         <source>Tools</source>
@@ -379,41 +368,41 @@ or press the shortcut again to stop recording</source>
     </message>
     <message>
         <source>Extract text</source>
-        <translation>识别文字</translation>
+        <translation>識別文字</translation>
     </message>
     <message>
         <source>Scrollshot</source>
-        <translation>滚动截图</translation>
+        <translation>滾動截圖</translation>
     </message>
     <message>
         <source>Pin screenshots</source>
-        <translation>贴图</translation>
+        <translation>貼圖</translation>
     </message>
     <message>
         <source>Start OCR</source>
-        <translation>快速启动图文识别</translation>
+        <translation>快速啟動圖文識別</translation>
     </message>
     <message>
         <source>Start scrollshot</source>
-        <translation>启动滚动截图</translation>
+        <translation>啟動滾動截圖</translation>
     </message>
     <message>
         <source>Arrow</source>
-        <translation>箭头</translation>
+        <translation>箭頭</translation>
     </message>
 </context>
 <context>
     <name>ShotStartPlugin</name>
     <message>
         <source>Screenshot</source>
-        <translation>截图</translation>
+        <translation>截圖</translation>
     </message>
 </context>
 <context>
     <name>ShotStartRecordPlugin</name>
     <message>
         <source>Record</source>
-        <translation>录屏</translation>
+        <translation>錄屏</translation>
     </message>
 </context>
 <context>
@@ -422,75 +411,66 @@ or press the shortcut again to stop recording</source>
         <source>Rectangle
 Press and hold Shift to draw a square</source>
         <translation>矩形
-按住Shift可画正方形</translation>
+按住Shift可畫正方形</translation>
     </message>
     <message>
         <source>Ellipse
 Press and hold Shift to draw a circle</source>
-        <translation>椭圆
-按住Shift可画圆形</translation>
+        <translation>橢圓
+按住Shift可畫圓形</translation>
     </message>
     <message>
         <source>Brush
 Press and hold Shift to draw a straight line</source>
-        <translation>笔刷
-按住Shift可画直线</translation>
+        <translation>筆刷
+按住Shift可畫直線</translation>
     </message>
     <message>
         <source>Adjust blur strength (Scroll to adjust it)</source>
-        <translation>调整模糊强度（鼠标滚轮）</translation>
+        <translation>調整模糊強度（滑鼠滾輪）</translation>
     </message>
     <message>
         <source>Adjust brush size (Scroll to adjust it)</source>
-        <translation>调整笔刷大小（鼠标滚轮）</translation>
+        <translation>調整筆刷大小（滑鼠滾輪）</translation>
     </message>
     <message>
         <source>Adjust text size (Scroll to adjust it)</source>
-        <translation>调整文字大小（鼠标滚轮）</translation>
-    </message>
-</context>
-<context>
-    <name>StartTooltip</name>
-    <message>
-        <source>Click or drag to
-select the area to record</source>
-        <translation>单击或拖动以
-选择要录制的区域</translation>
+        <translation>調整文字大小（滑鼠滾輪）</translation>
     </message>
 </context>
 <context>
     <name>SubToolWidget</name>
     <message>
         <source>Show keystroke (K)</source>
-        <translation>显示按键 K</translation>
+        <translation>顯示按鍵 K</translation>
     </message>
     <message>
         <source>Hide Keystroke (K)</source>
-        <translation>隐藏按键 K</translation>
+        <translation>隱藏按鍵 K</translation>
     </message>
     <message>
         <source>Show Keystroke (K)</source>
-        <translation>显示按键 K</translation>
+        <translation>顯示按鍵 K</translation>
     </message>
     <message>
         <source>Turn on camera (C)</source>
-        <translation>开启摄像头 C</translation>
+        <translation>開啟攝像頭 C</translation>
     </message>
     <message>
         <source>Turn off camera (C)</source>
-        <translation>关闭摄像头 C</translation>
+        <translation>關閉攝像頭 C</translation>
     </message>
     <message>
         <source>Screenshot</source>
-        <translation>截图</translation>
+        <translation>截圖</translation>
     </message>
     <message>
         <source>Settings</source>
-        <translation>设置</translation>
+        <translation>設定</translation>
     </message>
     <message>
         <source>Settings (F3)</source>
-        <translation>设置 F3</translation>
+        <translation>設定 F3</translation>
     </message>
     <message>
         <source>Format:</source>
@@ -514,7 +494,7 @@ select the area to record</source>
     </message>
     <message>
         <source>FPS:</source>
-        <translation>帧数：</translation>
+        <translation>幀數：</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -538,31 +518,31 @@ select the area to record</source>
     </message>
     <message>
         <source>Sound</source>
-        <translation>声音</translation>
+        <translation>聲音</translation>
     </message>
     <message>
         <source>Microphone</source>
-        <translation>麦克风</translation>
+        <translation>麥克風</translation>
     </message>
     <message>
         <source>System audio</source>
-        <translation>系统音频</translation>
+        <translation>系統音頻</translation>
     </message>
     <message>
         <source>Options</source>
-        <translation>选项</translation>
+        <translation>選項</translation>
     </message>
     <message>
         <source>Show pointer</source>
-        <translation>显示光标</translation>
+        <translation>顯示游標</translation>
     </message>
     <message>
         <source>Show click</source>
-        <translation>显示鼠标点击</translation>
+        <translation>顯示滑鼠點擊</translation>
     </message>
     <message>
         <source>Save to</source>
-        <translation>保存到</translation>
+        <translation>保存方式</translation>
     </message>
     <message>
         <source>Desktop</source>
@@ -570,35 +550,23 @@ select the area to record</source>
     </message>
     <message>
         <source>Videos</source>
-        <translation>视频</translation>
-    </message>
-    <message>
-        <source>Rectangle (R)
-Press and hold Shift to draw a square</source>
-        <translation>矩形（R）
-按住Shift可画正方形</translation>
-    </message>
-    <message>
-        <source>Ellipse (O)
-Press and hold Shift to draw a circle</source>
-        <translation>椭圆（O）
-按住Shift可画圆形</translation>
+        <translation>視頻</translation>
     </message>
     <message>
         <source>Line (L)
 Press and hold Shift to draw a vertical or horizontal line</source>
-        <translation>直线（L）
-按住Shift可画垂直线和水平线</translation>
+        <translation>直線（L）
+按住Shift可畫垂直線和水平線</translation>
     </message>
     <message>
         <source>Arrow (X)
 Press and hold Shift to draw a vertical or horizontal arrow</source>
-        <translation>箭头（X）
-按住Shift可画垂直和水平箭头</translation>
+        <translation>箭頭（X）
+按住Shift可畫垂直和水平箭頭</translation>
     </message>
     <message>
         <source>Pencil (P)</source>
-        <translation>画笔 P</translation>
+        <translation>畫筆 P</translation>
     </message>
     <message>
         <source>Blur (B)</source>
@@ -610,43 +578,35 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
     </message>
     <message>
         <source>Scrollshot (Alt+I）</source>
-        <translation>滚动截图 Alt+I</translation>
+        <translation>滾動截圖 Alt+I</translation>
     </message>
     <message>
         <source>Extract text (Alt+O）</source>
-        <translation>识别文字 Alt+O</translation>
+        <translation>識別文字 Alt+O</translation>
     </message>
     <message>
         <source>Pin screenshots (Alt+P）</source>
-        <translation>贴图 Alt+P</translation>
+        <translation>貼圖 Alt+P</translation>
     </message>
     <message>
         <source>Undo (Ctrl+Z)</source>
-        <translation>撤销 Ctrl+Z</translation>
+        <translation>撤銷 Ctrl+Z</translation>
     </message>
     <message>
         <source>Record</source>
-        <translation>录屏</translation>
-    </message>
-    <message>
-        <source>Clipboard</source>
-        <translation>剪贴板</translation>
+        <translation>錄屏</translation>
     </message>
     <message>
         <source>Pictures</source>
-        <translation>图片</translation>
-    </message>
-    <message>
-        <source>Folder</source>
-        <translation>指定位置</translation>
+        <translation>圖片</translation>
     </message>
     <message>
         <source>Set a path on save</source>
-        <translation>保存时设置位置</translation>
+        <translation>保存時設定位置</translation>
     </message>
     <message>
         <source>Change the path on save</source>
-        <translation>保存时更新位置</translation>
+        <translation>保存時更新位置</translation>
     </message>
     <message>
         <source>Format</source>
@@ -666,11 +626,11 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
     </message>
     <message>
         <source>Border Effects</source>
-        <translation>边框效果</translation>
+        <translation>邊框效果</translation>
     </message>
     <message>
         <source>None</source>
-        <translation>无边框</translation>
+        <translation>無邊框</translation>
     </message>
     <message>
         <source>Shadow</source>
@@ -678,51 +638,90 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
     </message>
     <message>
         <source>Border</source>
-        <translation>外边框</translation>
+        <translation>外邊框</translation>
     </message>
     <message>
         <source>Device</source>
-        <translation>样机</translation>
+        <translation>樣機</translation>
     </message>
     <message>
         <source>Extract Text</source>
-        <translation>识别文字</translation>
+        <translation>識別文字</translation>
+    </message>
+    <message>
+        <source>Save to local</source>
+        <translation>保存到本地</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>指定位置</translation>
+    </message>
+    <message>
+        <source>Custom Location</source>
+        <translation>自定義位置</translation>
+    </message>
+    <message>
+        <source>Each inquiry</source>
+        <translation>每次詢問</translation>
+    </message>
+    <message>
+        <source>Update location on save</source>
+        <translation>保存時更新位置</translation>
+    </message>
+    <message>
+        <source>Geometric Tools (R)
+Hold down Shift to draw squares or circles.</source>
+        <translation>幾何工具 (R)
+按住Shift可畫正方形/正圓</translation>
+    </message>
+    <message>
+        <source>Save to %1</source>
+        <translation>保存到%1</translation>
+    </message>
+    <message>
+        <source>Save to desktop</source>
+        <translation>保存到桌面</translation>
+    </message>
+    <message>
+        <source>Save to pictures</source>
+        <translation>保存到圖片</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>保存到桌面</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>保存到圖片</translation>
     </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
     <message>
         <source>Close (Esc)</source>
-        <translation>关闭 Esc</translation>
+        <translation>關閉 Esc</translation>
     </message>
     <message>
-        <source>OK (Enter)</source>
-        <translation>确认 Enter</translation>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>複製到剪貼板 Enter</translation>
     </message>
 </context>
 <context>
     <name>TopTips</name>
     <message>
         <source> Adjust the recording area within %1*%2 to get better video effect</source>
-        <translation> 调整录制区域范围在%1*%2以内，视频效果更佳</translation>
+        <translation> 調整錄製區域範圍在%1*%2以內，視頻效果更佳</translation>
     </message>
 </context>
 <context>
     <name>Utils</name>
     <message>
         <source>Screen recording is not supported at present</source>
-        <translation>录屏功能暂不可用</translation>
+        <translation>錄屏功能暫不可用</translation>
     </message>
     <message>
         <source>Exit</source>
-        <translation>退出</translation>
-    </message>
-</context>
-<context>
-    <name>VoiceRecordProcess</name>
-    <message>
-        <source>New recording</source>
-        <translation>新录音</translation>
+        <translation>離開</translation>
     </message>
 </context>
 </TS>
